Package 'imuGAP'

Title: Immunity: Geographic and Age-Based Projection
Description: Fits Bayesian hierarchical models of vaccine coverage by location, birth cohort, and age. Observations of vaccination status (which may span cohorts, ages, and doses) are used to fit a latent survival-style process model that decomposes coverage into a lifetime propensity to vaccinate and a time-varying force of vaccination. Hierarchical spatial structure (e.g., state, county, school) supports partial pooling via random effects. Models are implemented in 'Stan' and fit via 'rstan'. Provides helpers to validate user-supplied input data, and to predict coverage from fitted models.
Authors: Carl Pearson [aut, cre] (ORCID: <https://orcid.org/0000-0003-0701-7860>), Claire Perrin Smith [aut] (ORCID: <https://orcid.org/0000-0003-1069-9460>), Kelly Zhen [ctb], Weston Voglesonger [ctb], Joshua Chen [ctb], Minjae Kung [ctb]
Maintainer: Carl Pearson <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-06-23 10:41:48 UTC
Source: https://github.com/accidda/imugap

Help Index